pub struct CdcSubscriber { /* private fields */ }Expand description
A subscriber that tracks its position in the CDC log.
Implementations
Sourceimpl CdcSubscriber
impl CdcSubscriber
Sourcepub fn new(log: Arc<CdcLog>, from_seq: u64) -> Self
pub fn new(log: Arc<CdcLog>, from_seq: u64) -> Self
Create a subscriber starting from the given sequence number.
Use 0 to start from the beginning of the buffer.
Sourcepub fn from_latest(log: Arc<CdcLog>) -> Self
pub fn from_latest(log: Arc<CdcLog>) -> Self
Create a subscriber starting from the current (latest) position.
Sourcepub fn with_tables(self, tables: Vec<String>) -> Self
pub fn with_tables(self, tables: Vec<String>) -> Self
Filter events to only include the given tables.
Sourcepub fn poll(&mut self, max_events: usize) -> CdcResult<Vec<CdcEvent>>
pub fn poll(&mut self, max_events: usize) -> CdcResult<Vec<CdcEvent>>
Poll for new events (non-blocking).