pub struct VersionPruner { /* private fields */ }Expand description
Version pruning filter
Determines which versions can be safely garbage collected.
Implementations
Sourceimpl VersionPruner
impl VersionPruner
pub fn new(config: RetentionConfig) -> Self
Sourcepub fn register_snapshot(&self, timestamp: Timestamp)
pub fn register_snapshot(&self, timestamp: Timestamp)
Register an active snapshot
Sourcepub fn unregister_snapshot(&self, timestamp: Timestamp)
pub fn unregister_snapshot(&self, timestamp: Timestamp)
Unregister a snapshot
Sourcepub fn oldest_snapshot(&self) -> Option<Timestamp>
pub fn oldest_snapshot(&self) -> Option<Timestamp>
Get the oldest active snapshot
Sourcepub fn can_prune_version(
&self,
version_timestamp: Timestamp,
is_latest: bool,
version_index: usize,
) -> bool
pub fn can_prune_version( &self, version_timestamp: Timestamp, is_latest: bool, version_index: usize, ) -> bool
Check if a version can be pruned
A version can be pruned if:
- It’s not the latest version
- It’s older than max_version_age
- No active snapshot needs it
A snapshot at time T needs all versions with timestamp <= T (these are the versions that were visible at snapshot time)
Sourcepub fn can_collect_tombstone(&self, tombstone_timestamp: Timestamp) -> bool
pub fn can_collect_tombstone(&self, tombstone_timestamp: Timestamp) -> bool
Check if a tombstone can be collected
A tombstone can be collected only if:
- It’s older than the grace period
- No active snapshot needs to see it
Sourcepub fn update_time(&self)
pub fn update_time(&self)
Update current time