#[repr(C)]pub struct C_DatabaseConfig {
pub wal_enabled: bool,
pub wal_enabled_set: bool,
pub sync_mode: u8,
pub sync_mode_set: bool,
pub memtable_size_bytes: u64,
pub group_commit: bool,
pub group_commit_set: bool,
pub default_index_policy: u8,
pub default_index_policy_set: bool,
}Expand description
C-compatible Database Configuration
All fields have sensible defaults when set to 0/false. This allows clients to only set the fields they care about.
Fields
wal_enabled: boolEnable WAL for durability (default: true if wal_enabled_set is false)
wal_enabled_set: boolWhether wal_enabled was explicitly set
sync_mode: u8Sync mode: 0=OFF, 1=NORMAL (default), 2=FULL
sync_mode_set: boolWhether sync_mode was explicitly set
memtable_size_bytes: u64Memtable size in bytes (0 = default 64MB)
group_commit: boolEnable group commit for throughput (default: true if group_commit_set is false)
group_commit_set: boolWhether group_commit was explicitly set
default_index_policy: u8Default index policy: 0=WriteOptimized, 1=Balanced (default), 2=ScanOptimized, 3=AppendOnly
default_index_policy_set: boolWhether default_index_policy was explicitly set