EventDrivenGroupCommit

Struct EventDrivenGroupCommit 

pub struct EventDrivenGroupCommit { /* private fields */ }
Event-driven group commit buffer with proper synchronization

Implementations

Source

impl EventDrivenGroupCommit

pub fn new<F>(flush_fn: F) -> Self
where F: Fn(&[u64]) -> Result<u64, String> + Send + Sync + 'static,

Create a new event-driven group commit buffer

Arguments
  • flush_fn - Callback that performs WAL fsync. Takes list of txn_ids, returns commit timestamp.
pub fn with_config<F>(flush_fn: F, config: GroupCommitConfig) -> Self
where F: Fn(&[u64]) -> Result<u64, String> + Send + Sync + 'static,

Create with custom configuration

pub fn start(&self) -> Result<(), String>

Start the background flush thread

pub fn stop(&self)

Stop the flush thread

pub fn is_running(&self) -> bool

Check if running

pub fn submit_and_wait(&self, txn_id: u64) -> Result<u64, String>

Submit a commit and wait for it to complete

This blocks until the transaction’s batch has been fsynced. Returns the commit timestamp on success.

pub fn flush_batch(&self)

Flush one batch of pending commits

Called by background flush thread or inline when needed.

pub fn flush_loop(&self)

Background flush loop (call from owner thread)

pub fn stats(&self) -> GroupCommitStatsV2

Get statistics for monitoring