pub struct ArenaKey<'a> { /* private fields */ }Expand description
Zero-copy key reference into arena memory
This is a lightweight handle to data stored in a KeyArena. The key is valid as long as the arena has not been reset.
Implementations