pub struct ColumnarMemtable { /* private fields */ }Expand description
Columnar memtable with skip-list-like concurrent access
Implementations
Sourceimpl ColumnarMemtable
impl ColumnarMemtable
Sourcepub fn new(schema: TableSchema, size_limit: usize) -> Self
pub fn new(schema: TableSchema, size_limit: usize) -> Self
Create a new columnar memtable
Sourcepub fn insert(&self, row_id: RowId, values: &[Option<&[u8]>]) -> Result<()>
pub fn insert(&self, row_id: RowId, values: &[Option<&[u8]>]) -> Result<()>
Insert a row
values must have the same length as schema columns
Sourcepub fn get(&self, row_id: RowId) -> Option<Vec<Option<Vec<u8>>>>
pub fn get(&self, row_id: RowId) -> Option<Vec<Option<Vec<u8>>>>
Get a row by row ID (O(log N) lookup via BTreeMap) Returns all column values for the row
Sourcepub fn get_columns(
&self,
row_id: RowId,
col_indices: &[usize],
) -> Option<Vec<Option<Vec<u8>>>>
pub fn get_columns( &self, row_id: RowId, col_indices: &[usize], ) -> Option<Vec<Option<Vec<u8>>>>
Get specific columns for a row by row ID
Sourcepub fn scan_range(
&self,
start: RowId,
end: RowId,
) -> Vec<(RowId, Vec<Option<Vec<u8>>>)>
pub fn scan_range( &self, start: RowId, end: RowId, ) -> Vec<(RowId, Vec<Option<Vec<u8>>>)>
Scan a range of row IDs, returning all matching rows
Sourcepub fn memory_bytes(&self) -> usize
pub fn memory_bytes(&self) -> usize
Get memory usage
Sourcepub fn schema(&self) -> &TableSchema
pub fn schema(&self) -> &TableSchema
Get schema