pub struct SegmentDescriptor {
pub id: u64,
pub level: u32,
pub col_refs: HashMap<String, ColumnStripeRef>,
pub min_row_id: RowId,
pub max_row_id: RowId,
pub row_count: u64,
pub min_timestamp: u64,
pub max_timestamp: u64,
pub is_tombstone: bool,
}Expand description
Segment descriptor with column stripe references
Instead of storing all column data inline, the segment stores references to column stripes which may be at different levels.
Fields
id: u64Segment ID
level: u32Level
col_refs: HashMap<String, ColumnStripeRef>Column stripe references (column name -> stripe ref)
min_row_id: RowIdMin row ID in segment
max_row_id: RowIdMax row ID in segment
row_count: u64Row count
min_timestamp: u64Min timestamp
max_timestamp: u64Max timestamp
is_tombstone: boolIs tombstone (deleted after compaction)