pub struct SsiManager { /* private fields */ }Expand description
Serializable Snapshot Isolation Manager
Provides serializable isolation level using SSI technique.
Usage
ⓘ
let ssi = SsiManager::new();
// Begin transaction
let (txn_id, snapshot_ts) = ssi.begin()?;
// Read (records rw-dependency)
let value = ssi.read(txn_id, key)?;
// Write (checks write-write conflicts)
ssi.write(txn_id, key, value)?;
// Commit (checks for dangerous structures)
ssi.commit(txn_id)?;Implementations
Sourceimpl SsiManager
impl SsiManager
Sourcepub fn record_read(
&self,
txn_id: TxnId,
key: &[u8],
) -> Result<(), SsiConflictError>
pub fn record_read( &self, txn_id: TxnId, key: &[u8], ) -> Result<(), SsiConflictError>
Record a read and check for rw-antidependencies
If another concurrent transaction wrote to this key after our snapshot, we have an rw-antidependency (T_reader →ʳʷ T_writer).
Sourcepub fn record_write(
&self,
txn_id: TxnId,
key: &[u8],
) -> Result<(), SsiConflictError>
pub fn record_write( &self, txn_id: TxnId, key: &[u8], ) -> Result<(), SsiConflictError>
Record a write and check for write-write conflicts
Uses first-updater-wins: if another transaction already wrote to this key after our snapshot, we must abort.
Sourcepub fn commit(&self, txn_id: TxnId) -> Result<Timestamp, SsiConflictError>
pub fn commit(&self, txn_id: TxnId) -> Result<Timestamp, SsiConflictError>
Commit a transaction
Checks for dangerous structures before allowing commit.
Sourcepub fn get_status(&self, txn_id: TxnId) -> Option<SsiTxnStatus>
pub fn get_status(&self, txn_id: TxnId) -> Option<SsiTxnStatus>
Get transaction status
Sourcepub fn get_snapshot_ts(&self, txn_id: TxnId) -> Option<Timestamp>
pub fn get_snapshot_ts(&self, txn_id: TxnId) -> Option<Timestamp>
Get snapshot timestamp for a transaction
Sourcepub fn is_visible(&self, txn_id: TxnId, version: &SsiVersionInfo) -> bool
pub fn is_visible(&self, txn_id: TxnId, version: &SsiVersionInfo) -> bool
Check if a version is visible to a transaction