pub struct BlockIndexReader<'a> { /* private fields */ }Expand description
Block index reader for loading block index entries on-demand
Implementations
Sourceimpl<'a> BlockIndexReader<'a>
impl<'a> BlockIndexReader<'a>
Sourcepub fn new(data: &'a [u8]) -> Self
pub fn new(data: &'a [u8]) -> Self
Create a new block index reader from the block index section
Sourcepub fn read_entry(&self, offset: usize) -> Result<BlockIndexEntry>
pub fn read_entry(&self, offset: usize) -> Result<BlockIndexEntry>
Read a single block index entry at the given offset
Sourcepub fn read_range(
&self,
start: usize,
end: usize,
) -> Result<Vec<BlockIndexEntry>>
pub fn read_range( &self, start: usize, end: usize, ) -> Result<Vec<BlockIndexEntry>>
Read a range of block index entries
Sourcepub fn find_block_for_key(
&self,
key: &TemporalKey,
start_offset: usize,
end_offset: usize,
) -> Result<Option<BlockIndexEntry>>
pub fn find_block_for_key( &self, key: &TemporalKey, start_offset: usize, end_offset: usize, ) -> Result<Option<BlockIndexEntry>>
Binary search for a key in a range of block index entries
Sourcepub fn find_blocks_for_range(
&self,
start_ts: u64,
end_ts: u64,
start_offset: usize,
end_offset: usize,
) -> Result<Vec<BlockIndexEntry>>
pub fn find_blocks_for_range( &self, start_ts: u64, end_ts: u64, start_offset: usize, end_offset: usize, ) -> Result<Vec<BlockIndexEntry>>
Find all blocks that overlap with a timestamp range
Sourcepub fn entry_count(&self) -> usize
pub fn entry_count(&self) -> usize
Get total number of entries in this reader’s range