pub struct FileMetadata {
pub file_number: u64,
pub file_size: u64,
pub smallest_key: Vec<u8>,
pub largest_key: Vec<u8>,
pub num_entries: u64,
pub min_seqno: u64,
pub max_seqno: u64,
pub path: PathBuf,
pub bloom_filter: Option<Arc<BloomFilterHandle>>,
pub being_compacted: bool,
}Expand description
Metadata for an SSTable file
Fields
file_number: u64Unique file number
file_size: u64File size in bytes
smallest_key: Vec<u8>Smallest key in file (for range queries)
largest_key: Vec<u8>Largest key in file (for range queries)
num_entries: u64Number of entries in file
min_seqno: u64Minimum sequence number in file
max_seqno: u64Maximum sequence number in file
path: PathBufPath to the file
bloom_filter: Option<Arc<BloomFilterHandle>>Bloom filter (if loaded)
being_compacted: boolWhether file is being compacted
Implementations
Sourceimpl FileMetadata
impl FileMetadata
Sourcepub fn may_contain(&self, key: &[u8]) -> bool
pub fn may_contain(&self, key: &[u8]) -> bool
Check if key might be in this file using bloom filter
Sourcepub fn overlaps_range(&self, start: &[u8], end: &[u8]) -> bool
pub fn overlaps_range(&self, start: &[u8], end: &[u8]) -> bool
Check if a key range overlaps with this file