pub struct SuperVersionHandle { /* private fields */ }Expand description
RAII handle for SuperVersion access
This provides a convenient way to access a SuperVersion with automatic cleanup. The handle can be cloned to share access across threads.
Implementations
Sourceimpl SuperVersionHandle
impl SuperVersionHandle
Sourcepub fn new(version_set: Arc<VersionSet>) -> Self
pub fn new(version_set: Arc<VersionSet>) -> Self
Create a new handle from a VersionSet
Sourcepub fn with_snapshot(version_set: Arc<VersionSet>, seqno: u64) -> Self
pub fn with_snapshot(version_set: Arc<VersionSet>, seqno: u64) -> Self
Create a handle with a registered snapshot
Sourcepub fn version(&self) -> &SuperVersion
pub fn version(&self) -> &SuperVersion
Get the SuperVersion
Sourcepub fn snapshot_seqno(&self) -> Option<u64>
pub fn snapshot_seqno(&self) -> Option<u64>
Get the snapshot sequence number (if any)