TransactionMode

Enum TransactionMode 

pub enum TransactionMode {
    ReadOnly,
    WriteOnly,
    ReadWrite,
}
Transaction mode for SSI optimization

By classifying transactions at begin time, we can skip expensive SSI tracking for the majority of transactions:

ModeSSI Read TrackingSSI Write TrackingCommit Overhead
ReadOnlyNoneNone~10 ns
WriteOnlyNoneFull~30 ns
ReadWriteFullFull~50 ns

Performance Analysis

For read-only transactions (typically 90% of workload):

Current:  T_txn = T_begin + N × (T_read + T_record) + T_commit
                = 100ns + N × (32ns + 50ns) + 50ns = 150ns + 82ns × N

ReadOnly: T_txn = T_begin_ro + N × T_read + T_commit_ro
                = 20ns + N × 32ns + 10ns = 30ns + 32ns × N

For N=100 reads: 8350ns → 3230ns (2.6× faster)

Variants



ReadOnly

Read-only transaction - skips ALL SSI tracking Cannot form rw-antidependency cycles (no writes to create outgoing edges) Safe to skip read_set, read_bloom, and commit validation entirely



WriteOnly

Write-only transaction - skips read tracking Cannot form incoming rw-edges (no reads from concurrent writers) Only needs write_set and write_bloom tracking



ReadWrite

Full read-write transaction (default) - complete SSI tracking May form both incoming and outgoing rw-edges Requires full validation at commit time

Implementations

Source

impl TransactionMode

pub fn tracks_reads(&self) -> bool

Check if this mode requires read tracking

pub fn tracks_writes(&self) -> bool

Check if this mode requires write tracking

pub fn needs_ssi_validation(&self) -> bool

Check if commit needs SSI validation