pub struct InternedTablePrefix { /* private fields */ }Expand description
Interned table prefix for repeated use
When performing many operations on the same table, pre-compute the “table/” prefix to avoid repeated string operations.
Implementations
Sourceimpl InternedTablePrefix
impl InternedTablePrefix
Sourcepub fn make_row_key(&self, row_id: u64) -> KeyBuffer
pub fn make_row_key(&self, row_id: u64) -> KeyBuffer
Sourcepub fn make_column_key(&self, row_id: u64, column: &str) -> KeyBuffer
pub fn make_column_key(&self, row_id: u64, column: &str) -> KeyBuffer
Sourcepub fn same_table(&self, other: &Self) -> bool
pub fn same_table(&self, other: &Self) -> bool
Check if two prefixes are for the same table